@@ -1,3 +1,11 @@
+# -*- coding: utf-8 -*-
+'''
+InteractionProtocol class
+=========================
+
+A datatype that accepts initial value and feature generator, and generates
+new values. This datatype uses `Entity` to specify an `agent` or a `subject`.
+'''
 import dataclasses
 
 from typing_extensions import Literal
@@ -6,7 +14,7 @@ from typing_extensions import Literal
 @dataclasses.dataclass
 class Entity:
     '''
-    The datatype to specify an `agent` or a `subject`. 
+    The datatype to specify an `agent` or a `subject`.
     Used in `InteractionProtocol`.
     '''
     name: str
